@@ -8,11 +8,11 @@ import aioredis
 
 class AioDispatchClient(object):
     @classmethod
-    async def create(cls, redis_host: str, redis_port: int):
+    async def create(cls, redis_host: str, redis_port: int, max_redis_pool_size: int = 16):
         result = AioDispatchClient(redis_host, redis_port)
         result.pool = await aioredis.create_pool(
             f'redis://{redis_host}:{redis_port}', encoding='utf-8',
-            minsize=1, maxsize=16)
+            minsize=1, maxsize=max_redis_pool_size)
         # result.redis = await aioredis.create_redis(f'redis://{redis_host}:{redis_port}', encoding='utf-8')
         return result
 
@@ -21,7 +21,7 @@ class AioDispatchClient(object):
         self.redis_port = redis_port
         self.pool = None
 
-    async def process(self, service_queue: str, data: str, timeout: int = 500):
+    async def process(self, service_queue: str, data: str, timeout: int = 500) -> DispatchResponseModel:
         reply_to = idtool.gen_uuid()
         correlation_id = idtool.gen_uuid()
         request = {
@@ -38,6 +38,6 @@ class AioDispatchClient(object):
             result = await conn.execute(b'BLPOP', reply_to, timeout)
             if result and result[0] == reply_to:
                 response = DispatchResponseModel.parse_obj(json.loads(result[1]))
-                if response.correlation_id == correlation_id and response.status == DispatchResponseStatus.OK:
-                    return response.data
-        return None
+                if response.correlation_id == correlation_id:
+                    return response
+        return DispatchResponseModel(status=DispatchResponseStatus.NO_RESPONSE_ERROR, data='Failed to get response from server')
