@@ -12,7 +12,7 @@ class DispatchClient:
         self.redis_port = redis_port
         self.pool = redis.ConnectionPool(host=redis_host, port=redis_port, decode_responses=True)
 
-    def process(self, service_queue: str, data: str, timeout: int = 500):
+    def process(self, service_queue: str, data: str, timeout: int = 500) -> DispatchResponseModel:
         r = redis.Redis(connection_pool=self.pool)
 
         reply_to = idtool.gen_uuid()
